@@ -3,7 +3,7 @@
 package POE::Resource::Sessions;
 
 use vars qw($VERSION);
-$VERSION = '1.354'; # NOTE - Should be #.### (three decimal places)
+$VERSION = '1.365'; # NOTE - Should be #.### (three decimal places)
 
 # These methods are folded into POE::Kernel;
 package POE::Kernel;
@@ -551,13 +551,13 @@ sub _data_ses_stop {
     $self->_dispatch_event(
       $parent, $self,
       EN_CHILD, ET_CHILD, [ CHILD_GAIN, $child ],
-      __FILE__, __LINE__, undef, time(), -__LINE__
+      __FILE__, __LINE__, undef, monotime(), -__LINE__
     );
     $self->_dispatch_event(
       $child, $self,
       EN_PARENT, ET_PARENT,
       [ $self->_data_ses_get_parent($child->ID), $parent, ],
-      __FILE__, __LINE__, undef, time(), -__LINE__
+      __FILE__, __LINE__, undef, monotime(), -__LINE__
     );
   }
 
@@ -568,7 +568,7 @@ sub _data_ses_stop {
   my $stop_return = $self->_dispatch_event(
     $session, $self->get_active_session(),
     EN_STOP, ET_STOP, [],
-    __FILE__, __LINE__, undef, time(), -__LINE__
+    __FILE__, __LINE__, undef, monotime(), -__LINE__
   );
 
   # If the departing session has a parent, notify it that the session
@@ -578,7 +578,7 @@ sub _data_ses_stop {
     $self->_dispatch_event(
       $parent, $self,
       EN_CHILD, ET_CHILD, [ CHILD_LOSE, $session, $stop_return ],
-      __FILE__, __LINE__, undef, time(), -__LINE__
+      __FILE__, __LINE__, undef, monotime(), -__LINE__
     );
   }
 
@@ -632,7 +632,7 @@ come and go.
 See L<POE::Kernel/Session Helper Methods> for friend methods between
 POE::Kernel and POE::Session classes.
 
-See L<POE::Kernel/Resources> for for public information about POE
+See L<POE::Kernel/Resources> for public information about POE
 resources.
 
 See L<POE::Resource> for general discussion about resources and the
